
# q-expansion of newform 3725.2.a.c, downloaded from the LMFDB on 12 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 3725
weight = 2
poly_data = [-39, 68, 76, -137, -48, 75, 12, -15, -1, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0], 1], [[-26, -3, 92, 19, -63, -9, 14, 1, -1], 4], [[51, -37, -117, 24, 72, -3, -15, 0, 1], 4], [[-91, 31, 185, -12, -94, 1, 17, 0, -1], 4], [[-87, 2, 225, 13, -137, -8, 29, 1, -2], 4], [[101, -38, -237, 5, 139, 6, -29, -1, 2], 4], [[-56, 16, 143, -9, -82, 1, 16, 0, -1], 2], [[-180, 49, 418, -13, -233, -5, 46, 1, -3], 4]]

hecke_ring_character_values = None
aps_data = [[0, 1, 0, 0, 0, 0, 0, 0, 0], [-1, 0, 0, 0, 0, 0, 0, 0, -1], [0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, -1, 0, 1, 0, -1, 1], [1, 0, 0, 0, -1, 0, 0, -1, 0], [0, 0, 0, 0, -1, 0, -1, 0, 1], [0, 0, 0, -1, 0, -1, 1, 1, 0], [4, 1, -1, -1, 0, 0, -1, 0, 0], [0, 1, -2, 0, -1, 0, 0, 1, 1], [-2, 0, -1, 0, 0, 0, 1, 0, 1], [3, -2, 0, -1, -1, -1, 1, -1, 0], [3, 1, 0, -2, 1, 3, 2, -3, 2], [1, -1, -1, -2, -1, -1, 2, -1, 0], [0, -1, -1, 0, -1, -3, -1, 0, 1], [1, -1, 1, 2, -1, -3, -2, -1, 0], [0, 0, 1, 2, -2, -2, -1, 0, 1], [5, 2, -1, 0, 1, 1, -1, 0, 0], [-1, -1, -1, 1, -3, -2, -1, 2, 0], [-3, 0, 0, -3, 2, 1, 0, 1, -1], [3, 1, 1, -1, 1, 2, 0, 0, 2], [1, -2, -1, -1, 0, -1, 1, -1, -2], [-2, 3, -1, 1, -3, 0, -2, 4, -1], [1, 1, 1, -1, -2, 2, 3, -2, 1], [-2, 1, 1, 1, -1, 0, 0, -2, -1], [-1, -3, -1, 0, 2, -3, -1, 1, -3], [2, -1, -1, -1, 1, 0, -2, -2, -1], [-1, 3, 1, 2, 0, -1, -1, -1, -1], [-1, -3, -1, 0, -3, -3, -2, 1, 0], [0, 3, -1, 1, -3, -4, -4, 2, -1], [5, -1, -2, -2, 0, -1, 0, 1, -2], [-4, 1, -1, 3, -3, -2, -2, 4, -1], [-3, -2, 2, 2, -1, 0, 2, 1, -2], [-1, -5, 5, 4, -1, -1, 0, -1, -6], [7, 2, -1, -4, 3, 3, 3, 0, 4], [1, 0, 0, 0, 0, 0, 0, 0, 0], [8, 0, -1, -1, 2, 2, 0, -3, 6], [3, 1, 1, -2, 2, -1, -1, 3, -1], [-3, -1, -2, 1, 2, -1, -1, 4, -1], [3, -3, 2, 1, 3, 3, 0, 0, 2], [-3, 2, 0, 2, 0, 0, 1, 4, 1], [-3, -1, -1, 0, -2, -7, -1, 5, -3], [-2, 0, 0, -2, -3, -2, 3, 0, -1], [-5, -3, 3, 2, -2, 1, 1, -3, 3], [2, -2, 0, 4, -4, -2, -2, -2, -2], [2, -2, 2, 0, 0, 0, 0, -2, 6], [1, 2, 2, 4, -1, -2, -5, 4, -4], [4, -8, 0, -1, -1, -1, 3, 1, 1], [-5, -3, 3, -3, 3, 2, 5, 3, 2], [2, 5, -3, -6, 0, 1, 0, 2, 4], [8, -1, -2, -1, 2, 6, 2, 0, 3], [2, 1, 1, -5, 0, 6, 1, -6, 2], [0, -1, 3, -4, 6, 1, 3, -3, -2], [0, -1, -3, -3, 0, 4, 5, 2, 0], [5, -2, 0, 3, 0, -1, -2, -3, 1], [-11, 5, 1, 4, 1, 1, -2, 1, 0], [0, 2, -4, 4, -8, -4, -6, 4, 2], [0, -3, 2, -1, 2, 6, 3, -2, 2], [4, 3, 0, 0, 5, 4, 2, -1, 3], [10, 1, 1, -1, 0, 4, -3, 2, 0], [0, 1, 4, 5, 3, 4, -2, -2, -1], [5, -3, -5, -1, 2, 4, 0, -5, 1], [-7, 2, 0, 3, -6, -1, -2, 3, -1], [-4, -6, 2, -2, 2, 4, 4, -2, 4], [0, 3, -3, 2, 1, -3, -4, 7, 1], [-2, 9, -3, -7, 1, 6, 6, 2, 5], [-3, -4, 2, 6, -1, -4, -2, 4, -10], [12, -3, 1, -1, 2, 2, -3, -2, 4], [-3, -2, -3, 5, -2, -3, -2, 5, 1], [-8, 1, 1, 3, 4, -6, -1, 4, -10], [-1, 4, -4, -3, -3, -1, 1, 5, 6], [3, 8, 0, 3, -2, 1, -10, 1, -1], [-1, -4, -2, 3, -5, -3, 1, -1, 2], [9, -4, 4, 3, 2, 5, 0, -5, 5], [1, -3, 1, -4, -3, -5, 2, -7, 2], [6, 0, 2, 4, 3, 8, 3, -6, 1], [-4, -2, 2, 0, 3, 0, 1, 0, -3], [9, 4, 2, -5, 8, 11, 6, -1, -1], [-5, 1, -1, 2, -5, -5, -6, 7, 0], [2, -5, 5, 2, -1, -1, 5, -3, -7], [2, 0, 6, 2, 1, 0, -3, -6, -3], [-6, 5, -3, 1, -4, -2, 5, 0, -2], [-1, -6, 4, -6, 6, 6, 7, -8, -1], [2, 8, -4, -4, -6, -2, -4, -2, 2], [-1, -6, 2, -1, 6, 1, -8, 1, -1], [2, 2, -4, 6, -3, 0, -3, 0, -3], [3, 3, 5, 2, 2, 3, 1, -1, 1], [9, 5, -3, 2, -1, 1, -4, 5, 2], [5, -5, 1, -2, -2, 3, 7, -3, -1], [-7, -2, -2, -1, -3, -11, -5, 7, -2], [-3, -2, 6, -3, -2, 7, 10, -7, 9], [14, -2, 2, -4, 1, 0, 1, -2, -1], [-11, -9, -7, -3, 4, 0, 3, 0, -1], [9, 0, -4, 4, -6, -8, -9, 7, -1], [8, 6, -3, -7, 6, 2, 2, -3, 10], [12, -4, -2, -1, -3, -3, -6, 4, -3], [11, -4, 4, 2, 1, 2, 6, -7, 0], [11, -7, 5, 2, 0, 1, 1, -3, 9], [-4, 4, 2, 6, 1, 2, -1, -2, -9], [-3, 4, 0, -1, 1, 5, -3, -5, -4], [-6, -1, 5, 5, 1, 2, -4, 2, -7], [2, -3, -3, -1, -3, 0, 0, 2, -1], [3, 4, -1, -3, 6, 5, -4, 1, -3], [2, 1, 1, 5, -8, -10, -7, 10, 0], [-8, 0, -2, 0, -4, -4, -8, 2, 2], [-11, 3, 7, 6, -6, -7, 3, 5, -5], [1, 5, -11, -3, -4, -6, 2, 2, -1], [16, 7, 1, -5, 2, 8, -1, -2, 4], [-10, 1, -1, -1, -1, 4, 2, -4, 3], [-2, -7, 5, 8, -4, -1, -6, 0, -2], [0, 8, -4, -9, 6, 9, 1, -3, 4], [12, 5, -3, -4, -7, 3, 6, -3, 5], [1, 3, 2, -2, 5, 5, 4, -1, -4], [-7, 7, 1, -2, 2, 11, 5, -1, 5], [9, 1, 3, 6, -2, -7, -3, 7, 1], [3, -8, 2, -7, 2, 1, 6, -1, -1], [-1, 8, 1, -5, 0, 1, 3, -7, 0], [-13, 4, -6, -3, 0, -1, 4, -3, 5], [-11, -5, 5, 7, -1, -6, -3, 9, -12], [1, -2, 0, -3, 4, -5, -6, 1, -1], [-13, -1, -5, 8, -3, -9, -2, 7, -10], [-7, 6, -10, -3, 0, -7, -8, 15, -3], [5, -6, -2, 1, -6, -3, -6, 1, 5], [-5, 4, -2, 1, 1, 3, -3, -7, 0], [-9, 2, -2, -5, 6, -1, 6, 1, -7], [12, 7, 5, 3, 5, 4, 4, -4, -7], [-9, 1, 1, 0, 0, 7, -3, -7, -5], [4, -3, -4, 3, -11, -4, -5, 2, 4], [0, -5, 5, 1, 3, 0, -12, 4, -1], [-4, 10, -7, -3, -5, 0, 3, 7, -1], [-1, -4, -2, -1, -3, -3, 1, 3, 4], [8, -2, 2, 6, 0, -6, -18, 0, -6], [-6, -4, -2, -7, 1, -1, 10, -4, 9], [-1, 9, -9, 4, -8, -7, -1, 9, 1], [-21, 0, 4, 5, 5, 5, 7, 5, -10], [-13, 6, 3, 3, -5, -1, -4, 7, 1], [4, 6, 7, 0, -9, 6, -1, -4, -1], [20, 5, -4, -3, 4, 6, -4, -10, 11], [-12, 9, -3, 13, -14, -12, -9, 12, -4], [8, -2, -2, -6, -1, -2, -1, -6, 9], [-1, -1, 0, -6, 2, -3, -5, 5, -5], [14, -11, 5, 6, 5, -3, 6, -1, -9], [-5, 0, 6, 5, -1, 3, -9, 5, -2], [-2, 3, 0, 4, 0, 0, -9, -7, -8], [6, -5, 11, 3, 8, -2, 3, 0, -4], [3, 3, 7, 6, 4, -3, -3, 5, -3], [21, -6, -1, -10, -2, 3, 6, -8, 9], [-13, 0, -10, 1, -4, -7, -2, 3, -5], [14, 4, 4, 5, -2, -1, -3, -1, -6], [11, 6, 10, 1, 7, 7, 1, 1, 0], [13, 2, 2, 1, 10, 13, -6, -5, 1], [3, 0, 2, 4, -2, -2, -11, 0, -9], [-6, -1, -1, 7, -6, -18, -1, 0, -2], [-15, 3, 3, 5, -2, -10, 1, 6, -3], [-4, 1, -7, -5, -4, -4, -1, 2, 10], [-7, -6, -2, -4, 1, -2, 2, 3, -6], [-13, 5, 3, 2, 3, -1, -2, 11, -4], [-2, 7, -3, -3, -6, -2, 5, -2, 4], [-8, 7, -6, 17, -11, -12, -9, 16, -6], [19, -2, 4, -3, 6, 1, 2, -7, 7], [3, 8, 1, -7, -2, 17, 0, -7, 9], [12, 12, 2, -8, 9, 6, -1, 0, -5], [10, 3, 3, -11, 6, 16, 5, -14, 10], [-7, -1, 5, 12, 0, -1, -9, 5, 5], [16, 3, -1, -6, 0, -5, 1, -1, 12], [9, 3, -1, -2, -1, 3, 2, -5, 4], [-3, 0, 4, 5, -7, -1, -7, 3, -2], [8, 1, 5, 4, 4, 3, -4, 8, -2], [-5, -1, -4, 6, -10, -5, 3, 3, 5], [-10, 5, 11, 5, 8, 4, 9, 2, 4], [-21, -3, -12, -6, 0, 1, 4, 5, 2], [-5, -8, 0, -3, 0, -3, -2, -5, -3], [-3, -1, -6, 2, -2, -5, -8, -1, -2], [-1, -2, -2, -10, 4, 8, 5, -5, 1], [14, 0, -6, 0, 1, -6, -7, -2, -5], [1, 15, -7, -6, 6, 5, 1, 3, 11], [24, 0, 4, 0, 1, 8, 3, -6, -1], [0, -1, -5, 0, 7, 9, 11, 2, -5], [-4, 10, -2, -10, 6, 6, 8, 6, 6], [9, 17, -5, -2, -5, 1, 2, 3, 10], [1, 5, -3, -5, 11, 0, 3, 2, 10], [21, 1, -1, -12, 3, 3, 8, -1, 2], [-4, 7, -5, -1, -5, -6, 4, 2, 3], [-21, 9, 3, 0, 1, 5, 10, -5, 0], [14, 1, -2, 5, 2, 6, -5, -6, -2], [0, -3, 1, -8, 5, 7, 1, -16, -5], [28, -5, -1, -1, -12, -4, -3, -6, 6], [13, 1, 5, 2, 8, 13, 1, -9, -7], [-2, 2, 6, 0, 18, 8, 4, 2, -6], [-5, -1, 3, -11, 13, 8, 9, -2, -6], [-8, -1, 3, 5, 6, 4, 1, 2, -6], [-1, 10, -4, -10, 0, -4, -1, 4, 3], [-6, -14, 6, 2, 1, 2, 15, -4, 5], [2, 3, -7, -10, 2, 1, 11, -3, -4], [9, -12, -2, -3, 8, 5, -2, -7, 1], [-11, 1, 5, 10, 3, -3, -2, 11, -4], [8, 0, -3, -4, 10, 14, 6, -2, -4], [-1, 2, -9, -7, 8, 9, 5, -3, 4], [36, -4, 2, 2, 2, -2, -4, -4, 10], [3, -12, -3, 5, -3, -1, 2, -3, 1], [14, 7, 9, 5, 3, 4, -10, -2, 1], [-30, -7, -4, 11, 4, -16, -10, 14, -17], [-15, 14, 0, 11, -3, 1, -3, 13, -8], [10, -1, -4, 3, -7, -6, 3, 12, 8], [-3, 0, -2, 1, 1, -11, -11, 9, -4], [-5, 17, 7, -6, 0, 13, 11, 3, 7], [9, 13, 4, 10, -7, -7, 1, 5, 3], [20, -4, 9, -1, -1, 0, 3, -5, -9], [11, 9, -1, -4, 6, 11, 9, -11, 15], [4, -10, 6, 2, 2, 8, 10, -16, 10], [22, -8, 1, 5, 0, 4, -4, -9, 14], [26, 6, -4, -6, 2, -4, 6, 10, 0], [1, 9, 1, -6, 2, 7, 3, 9, 9], [22, 9, 4, 6, -7, 2, -8, 3, 1], [5, -14, 8, -10, 16, 10, 10, -14, 5], [-14, -4, 4, 8, -4, 2, -8, 2, 10], [-15, -2, 9, 9, -1, -3, 4, 7, 3], [4, 2, 2, -1, 4, 1, -4, 1, -6], [-12, 2, -2, -1, 1, -3, -10, 5, 9], [17, -2, -8, -9, 1, 11, 5, -5, 14], [-41, -6, 4, 11, -1, -11, -3, 15, -14], [7, -1, -9, -4, 0, 1, -9, -3, 11], [-4, -11, 17, 14, 1, -3, -13, -4, -9], [13, -9, -8, 2, 5, 7, 4, -7, -2], [-9, 7, -1, 8, 1, 11, 0, 5, 4], [6, -9, 15, -13, 14, 16, 15, -12, 0], [0, -7, -4, -7, 7, 10, 18, -4, 1], [-19, -11, 5, 10, -1, 3, 2, -1, -8], [-6, 6, -4, -9, 5, 15, 11, -11, 1], [-6, -3, 0, -4, -4, 0, 13, -5, 0], [0, 9, -15, -3, -9, 0, 0, 12, 11], [13, -4, 14, -4, 11, 2, 0, -2, -6], [12, 2, -4, 2, -3, 12, 1, -16, 11], [-7, -18, 0, 3, -8, -7, 4, 7, 1], [-12, 15, 5, 14, -2, -11, -12, 15, -16], [-12, 0, 0, 0, -1, 10, -3, -12, 5], [-10, -5, 4, 2, -3, -10, -2, -7, -7], [-1, -7, -2, 6, 3, -5, 0, -3, -12], [1, -19, -9, -6, 1, -1, 0, 1, 4], [-4, 3, 3, 1, 5, 0, 8, 4, -23], [22, 3, 11, 5, -1, 0, 4, -8, 1], [-1, -7, -9, 0, -6, -9, -1, 15, -11], [19, -6, 6, 0, 1, 6, 9, -16, 12], [9, -9, 17, -6, 9, 15, 16, -13, -14], [13, -3, 5, 2, -13, -7, 4, 1, 14], [15, -8, -9, -5, 5, 1, -11, -5, -2], [-11, 7, 3, -4, 8, 5, 11, -5, -9], [-20, -3, 5, 8, 2, -17, -2, 10, -10], [-2, -12, 8, -2, 6, -8, 8, -2, -16], [20, -9, 16, 0, -6, -2, 3, -11, 8], [-1, 5, 1, -5, 0, -6, -7, 14, -15], [-15, -4, 6, 9, -4, -1, 6, -5, 1], [-5, 1, -7, -10, -9, -5, 10, -1, 0], [-12, 8, -2, -7, 8, -5, -2, 7, 2], [8, -19, 0, 7, 5, 4, -3, -4, 2], [3, -12, 5, 9, 6, -7, -4, -3, 1], [-25, -7, 1, 6, 6, -5, -7, 5, -9], [-3, -11, -1, 6, -4, -5, 1, -1, -7], [-3, -12, -2, 6, 7, 4, 5, -6, 0], [-4, 10, -14, -14, 4, 6, 0, 2, 4], [8, 7, -5, 11, -13, -16, -22, 14, -1], [-17, 1, 7, -8, 0, 7, 13, -5, 5], [-13, 9, -7, -4, 1, 3, 10, 5, 0], [5, -3, -3, -1, 0, 12, 0, -8, 15], [0, -3, -1, -4, -2, 3, 12, 11, -6], [-11, 15, 5, 6, 13, 7, 0, -1, -8], [33, -6, -6, -9, -3, 15, 11, -9, 14], [-5, -12, 14, 1, 1, -3, -5, -1, -14], [-28, -12, -3, 8, -3, -16, -8, 4, -12], [10, 10, -6, 1, 2, -5, 2, 7, -6], [-13, -10, 10, 3, 4, 11, 4, -15, 3], [12, -14, 14, -10, 11, 16, 11, -10, 1], [19, 4, 7, -10, 16, 17, 4, -14, 9], [-18, -2, 6, 7, 5, -1, 2, 5, -23], [-19, 7, -5, -8, -3, -7, 2, -1, -12], [-18, 10, -6, 0, -3, -4, -1, -2, 13], [2, -7, 9, 1, 4, -4, 9, -6, -14], [-5, -9, -9, 2, -6, -3, 3, 15, -1], [-7, 4, 11, 1, 1, 3, 1, 1, -8], [16, 3, -9, -1, -7, -4, 2, -2, 5], [21, -6, 1, 8, -8, -5, -4, -2, 15], [7, -6, 2, -11, 14, 13, 22, -9, 5], [3, -9, -2, -3, -10, -11, 1, 12, -3], [-30, 12, 1, 7, -6, 0, -8, 9, 12], [8, 0, 8, 7, -11, -3, 0, -9, 3], [-2, -1, -9, -1, -6, 6, 1, 0, 0], [-7, -2, -2, -11, 8, 9, 0, -5, -3], [2, 18, 3, 0, 12, 20, 6, -4, 4], [-9, -2, 6, -1, -9, -3, -7, -5, 8], [7, -7, 3, 5, 3, 6, 6, 0, 0], [-10, -6, 0, 2, -3, 6, 5, -12, 9], [-8, 0, -12, 1, -11, -17, -10, 1, 3], [-4, 12, -10, 10, -5, -6, -15, 14, -1], [-38, -11, -5, 9, -17, -18, 2, 12, -3], [-1, 1, -1, 4, -10, 11, 1, -11, 7], [21, -9, -2, -2, 2, 15, 18, -15, 8], [-13, 6, -6, -1, -1, -5, 15, -3, 0], [13, 8, 8, -2, 0, 14, -1, -9, -3], [7, 8, -2, 6, 1, -2, -12, -8, 0], [-13, 9, 5, 0, -10, 5, -1, 3, 1], [-15, 9, -5, 5, -5, -6, -13, -1, -2], [-2, -1, 5, -7, 11, 10, 12, -12, -3], [-17, -6, 0, 9, 1, -15, 5, 5, -12], [-1, -14, -7, 4, -7, -13, -9, 0, -2], [-4, 6, -9, 3, 11, 8, -1, 1, -1], [-27, -2, 11, 8, -5, -3, 5, 8, -10], [-15, 19, -21, 0, -11, -3, -4, 7, 8], [11, -1, 5, 5, 0, -16, -6, -11, -3], [-17, -2, -8, 13, 2, -13, -8, 21, -9], [-6, -6, 2, -2, 0, -4, 0, 8, -16], [-14, -4, -19, 4, -3, -16, -5, 14, -17], [-16, -8, 11, 9, 8, -2, 0, -1, -20], [-2, -5, -3, 0, -7, 5, 9, -5, 11], [-2, 0, -3, 4, -1, 12, 1, 10, 13], [-6, -9, 3, -5, 0, -18, 7, 4, -6], [28, -10, 12, 8, 1, -6, -5, 6, 7], [-16, 16, -12, 8, -10, -20, -18, 14, -6], [15, -9, -12, -11, -5, -5, -4, 6, 2], [-3, -6, -8, -15, 16, 7, 18, -9, 5], [15, 0, -4, 3, -3, -13, -19, -1, -2], [10, 2, -10, 0, -10, -10, -6, 14, -4], [-3, 7, -1, 6, 3, -3, 2, 5, -6], [-5, 0, -8, 1, 8, 3, -6, 1, -1], [-24, -1, -1, 3, -6, -12, -5, 2, -2], [5, -20, 2, -6, 0, -8, -8, 0, -3], [-13, 4, 1, 7, 0, 1, 3, 17, -8], [-9, 6, 4, 1, 6, -1, -2, -3, -3], [-13, 15, 0, 3, 11, -5, -10, 8, -14], [-9, 8, 12, 10, -9, 6, -11, 0, 2], [-39, -7, -9, -4, 1, 3, 6, 1, -4], [33, 5, 1, -11, 12, 14, 6, -6, 7], [0, 16, 10, 0, -2, 16, 2, -8, 6], [7, -8, 10, -9, -1, 5, -9, -9, 12], [14, 0, 10, -10, -2, 6, 10, -8, 24], [29, -6, -11, -20, 3, 21, 11, -4, 14], [4, 12, -18, -10, 6, 6, -8, 14, 10], [14, 16, 2, 7, -6, 5, 5, 0, 22], [-8, 12, 8, 4, 3, -2, -5, -2, -15], [-55, -3, 9, 0, 0, 3, 3, -7, 1], [8, 26, -2, -5, 4, 17, 5, 3, 16], [-23, -10, 0, 2, -1, -10, 11, 4, 0], [4, 7, 15, 9, 2, -8, -1, 6, -8], [15, -29, 11, 10, -10, -9, 7, -7, -5], [24, -17, -7, -1, 12, -4, -9, -4, 0], [-4, -3, -1, -5, -3, 0, -4, -8, 3], [-7, 16, 0, 11, -10, -11, -14, 23, -13], [-29, 22, 0, -13, 1, -3, 1, 7, -4], [2, -1, 7, -3, 5, -8, -4, 4, 7], [-17, 7, -7, 4, -16, -7, -15, 17, 1], [6, 0, -14, -6, -6, -4, -2, 10, 0], [-24, -9, -3, 7, -13, -14, 4, 18, -1], [30, 4, -2, -13, 2, 9, 1, 2, 4], [-7, 0, 14, -6, 6, 12, 9, -14, 13], [-4, -5, -5, 17, -12, -18, -15, 0, -10], [-7, 3, -11, 6, -3, -15, -14, 11, -14], [15, 4, 3, 7, 0, -3, -9, 7, 16], [5, 3, -5, -6, 0, -1, 17, -5, -5], [5, -2, -2, -14, 17, 24, 8, -13, -6], [-10, -4, 10, -10, 16, 30, 24, -12, -8], [-2, -12, 21, -6, 12, 20, 24, -20, 8], [-28, 7, 1, 1, -7, 0, 2, 18, 7], [11, -3, 6, -2, 5, 5, -6, 3, -4], [-15, 2, -6, 5, 2, 7, 8, 5, 5], [-38, -6, 4, 4, -2, 4, 6, 4, -2], [-29, -12, 13, 10, 1, -1, -1, -4, -2], [-22, 18, -10, 9, 4, -5, -16, 15, -12], [30, 5, -13, -25, 20, 16, 19, -6, 16], [-20, 14, -6, -4, -19, -10, 11, 2, -5], [-6, 22, 8, 0, -1, 4, 3, 4, -1], [-1, -10, -2, -3, -9, -9, 3, 23, 18], [2, -18, 16, 14, -1, 0, -5, 0, -9], [21, 8, -4, -7, -4, -5, -10, -1, -13], [12, 11, 0, -6, 8, 2, 11, 3, -6], [-2, -7, 0, 19, -15, -22, 0, 16, 3], [3, 3, -7, -11, -2, -8, 8, -5, -15], [-24, -10, -1, -10, -2, -8, 16, 0, 6], [13, 11, 1, -14, 18, 15, 5, -5, 9], [1, 3, -12, -7, -19, -11, 0, 22, 14], [-9, 18, -6, 5, -7, 5, -11, -1, 8], [-17, 2, 0, 5, 8, 1, -16, -3, -17], [-6, 9, 5, -1, 12, 6, 5, 0, -8], [-2, -5, 9, 31, -15, -22, -14, 16, -5], [-18, 7, 1, 2, 2, 7, -12, 3, 0], [-16, 24, -12, -2, -6, 4, -2, 8, 0], [-7, 2, 3, -1, 9, -1, -9, 17, 4], [30, -5, 1, 2, -3, -15, 4, 3, -5], [-2, 12, -6, 8, -9, -2, -9, 16, 7], [-5, -13, -8, 7, -12, -23, -5, 22, -9], [1, -5, -12, -16, 10, 7, 11, 3, 17], [-7, -5, 13, 6, 1, 3, 2, 3, 2], [-8, 14, -8, -2, 8, 10, -12, 2, -10], [-16, -21, 5, -14, 7, 1, 17, -11, 1], [18, -5, -13, -23, 7, 10, 14, -10, 9], [13, 1, -15, -2, -6, -5, -9, -9, 5], [21, -15, -9, -18, 3, 13, 20, -15, -6], [0, -1, 11, -1, -12, -20, -1, 20, 0], [-24, 21, -14, 9, -16, -2, -10, 14, 17], [13, 5, -13, -18, -6, -15, 5, 11, 5], [-19, 13, -2, 16, -13, -13, -8, 9, 4], [-11, 16, -2, -1, -8, -7, 6, 1, 1], [14, -10, 4, -20, 23, 18, 19, -18, 1], [8, 4, 1, 6, 4, 10, -7, -4, 11], [4, -1, 3, -13, -10, -2, 5, -4, 18], [12, 12, -22, -12, -8, -8, -10, 20, -4], [4, 15, -22, -17, 11, 8, 8, 14, 15], [-4, -21, -7, -6, 4, 11, 4, -5, 8], [3, 12, -5, -14, -7, -1, -3, 0, 14], [-24, 12, 4, 4, -6, 0, 8, 8, -2], [8, -1, 6, -5, 5, 0, 10, -2, 21], [-55, 8, -4, 15, -10, -17, -20, 11, -7], [-4, 1, -9, 14, -4, -17, -1, 23, -8], [5, -6, 0, 1, 4, 9, -8, -7, 13], [4, -5, -16, -13, 1, 4, 2, -6, 13], [0, 11, -4, 12, -4, 6, -7, 1, 2], [3, -19, -5, 16, -4, -5, -3, -11, 5], [-16, -8, 11, 10, 7, 6, -7, 12, -9], [-13, 16, -10, -18, 1, 8, 6, -8, 10], [-7, -20, 8, 14, 8, -18, -25, -3, -21], [-3, -4, -4, 7, -10, -15, -4, -5, 15], [1, -4, -2, 11, -12, -23, -2, 17, -1], [-20, -18, 4, -1, 3, -21, -8, 14, -27], [25, 5, 1, -20, 1, 7, -8, -9, -2], [1, 1, 6, 4, 16, -13, -8, 17, 0], [-29, 12, -8, 1, 4, 3, 0, -7, 1], [-6, -2, 1, -1, 14, 0, -10, 3, -20], [2, -10, 22, 2, 1, 0, 9, -16, -25], [11, -9, -3, -8, -14, 3, -3, -11, -1], [-9, -18, 18, 11, 9, 7, 1, -9, -12], [-30, 11, 11, 5, 13, 18, 20, 2, -13], [54, 9, -1, 1, -5, -8, -10, 4, -5], [-43, -12, 6, 21, 7, -11, -3, 25, -18]]
